use anyhow::anyhow;
use once_cell::sync::OnceCell;
use reqwest::multipart::{Form, Part};
use reqwest::{Body, Client};
use serde_json::Value;

static CLIENT: OnceCell<Client> = OnceCell::new();

pub async fn upload_webhook<T: Into<Body>>(
    webhook: &str,
    file: T,
    filename: &str,
) -> anyhow::Result<String> {
    let client = CLIENT.get_or_init(Client::new);
    let form = Form::new().part("file", Part::stream(file).file_name(filename.to_string()));
    let req = client
        .post(webhook)
        .multipart(form)
        .send()
        .await?
        .json::<Value>()
        .await?;
    if let Some(url) = req["attachments"][0]["url"].as_str() {
        Ok(url.into())
    } else {
        Err(anyhow!("Discord didn't include the URL in the response"))
    }
}
